@@ -43,10 +43,19 @@ class AlarmDisplayClock(clock.Clock):
                 h = h % 12
                 abrv = "PM"
 
-        text = str(h).zfill(2) + ":" + str(self.time.minute).zfill(2)
+        if self.pad_zeros :
+            fill_char = '0'
+        else :
+            fill_char = ' '
+
+        text = str(h).rjust(2, fill_char) + ":" + str(self.time.minute).zfill(2)
         if self.show_seconds :
             text = text + ":" + str(self.time.second).zfill(2)
         
+        if self.font_name.startswith("Klingon") :
+            text = clock.to_klingon_digits(text)
+            abrv = clock.to_klingon_text(abrv)
+
         self.context.text_path(text)
 
         if self.fill :
@@ -80,10 +89,14 @@ class AlarmDisplayClock(clock.Clock):
                     h = h % 12
                     abrv = "PM"
 
-            text = str(h).zfill(2) + ":" + str(self.alarm_time.minute).zfill(2)
+            text = str(h).rjust(2, fill_char) + ":" + str(self.alarm_time.minute).zfill(2)
             if self.show_seconds :
                 text = text + ":" + str(self.alarm_time.second).zfill(2)
         
+            if self.font_name.startswith("Klingon") :
+                text = clock.to_klingon_digits(text)
+                abrv = clock.to_klingon_text(abrv)
+
             self.context.text_path(text)
 
             if self.fill :
@@ -109,18 +122,25 @@ class AlarmDisplayClock(clock.Clock):
         pass
 
     def resize(self):
+        abrv = "AM"
         self.context.set_font_size(int(self.text_scaling * 20))
+      
         if self.show_seconds :
-            self.text_width = self.context.text_extents("00:00:00")[2]
+            text = "00:00:00"
         else:
-            self.text_width = self.context.text_extents("00:00")[2]
+            text = "00:00"
 
+        if self.font_name.startswith("Klingon") :
+            text = clock.to_klingon_digits(text)
+            abrv = clock.to_klingon_text(abrv)
+
+        self.text_width = self.context.text_extents(text)[2]
         self.text_width *= 1.1
 
         if self.twelve_hour_mode :
             self.text_width += self.context.text_extents("..")[2]
             self.context.set_font_size(int(self.text_scaling * 10))
-            self.abrv_width = self.context.text_extents("AM")[2]
+            self.abrv_width = self.context.text_extents(abrv)[2]
             self.abrv_width *= 1.1
         else :
             self.abrv_width = 0
