@@ -47,10 +47,14 @@ class DecimalClock(clock.Clock):
         else :
             fill_char = ' '
 
-        text = str(h).rjust(2, fill_char) + ":" + str(self.time.minute).rjust(2, fill_char)
+        text = str(h).rjust(2, fill_char) + ":" + str(self.time.minute).zfill(2)
         if self.show_seconds :
-            text = text + ":" + str(self.time.second).rjust(2, fill_char)
+            text = text + ":" + str(self.time.second).zfill(2)
         
+        if self.font_name.startswith("Klingon") :
+            text = clock.to_klingon_digits(text)
+            abrv = clock.to_klingon_text(abrv)
+
         self.context.text_path(text)
         if self.fill :
             self.context.fill()
@@ -65,17 +69,24 @@ class DecimalClock(clock.Clock):
             self.context.stroke()
 
     def resize(self):
+        abrv = "AM"
         self.context.set_font_size(int(self.text_scaling * 45))
+      
         if self.show_seconds :
-            self.text_width = self.context.text_extents("00:00:00")[2]
+            text = "00:00:00"
         else:
-            self.text_width = self.context.text_extents("00:00")[2]
+            text = "00:00"
 
+        if self.font_name.startswith("Klingon") :
+            text = clock.to_klingon_digits(text)
+            abrv = clock.to_klingon_text(abrv)
+
+        self.text_width = self.context.text_extents(text)[2]
         self.text_width *= 1.1
 
         if self.twelve_hour_mode :
             self.context.set_font_size(int(self.text_scaling * 20))
-            self.abrv_width = self.context.text_extents("AM")[2]
+            self.abrv_width = self.context.text_extents(abrv)[2]
             self.abrv_width *= 1.1
         else :
             self.abrv_width = 0
