@@ -58,14 +58,14 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         self.time = None
         self.old_time = None
 
-        button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Advanced Clock")
-        image = gtk.Image()
-        image.set_from_file("/usr/share/icons/hicolor/64x64/apps/advanced-clock-plugin.png")
-        button.set_image(image)
-        button.set_alignment(0, 0.5, 0, 0)
-        button.connect("clicked", self.settings_cb)
-        self.add(button)
-        button.show()
+#        button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Advanced Clock")
+#        image = gtk.Image()
+#        image.set_from_file("/usr/share/icons/hicolor/64x64/apps/advanced-clock-plugin.png")
+#        button.set_image(image)
+#        button.set_alignment(0, 0.5, 0, 0)
+#        button.connect("clicked", self.settings_cb)
+#        self.add(button)
+#        button.show()
 
         self.drawing_area = gtk.DrawingArea()
       	self.drawing_area.connect("expose-event", self.expose_cb)
@@ -75,7 +75,7 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         self.clock = getattr(clocks[clock_names.index(self.clock_name)], self.clock_name)(self.drawing_area)
         self.clock.request_resize()
 
-        self.show()
+ #       self.show()
 
         gobject.timeout_add(1000, self.update_cb)
 
